==> CGAL-6.0-doc_html.tar.xz: doc_html/Point_set_processing_3/examples.js <==
var examples =
[
    [ "Point_set_processing_3/read_write_xyz_point_set_example.cpp", "Point_set_processing_3_2read_write_xyz_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/read_ply_points_with_colors_example.cpp", "Point_set_processing_3_2read_ply_points_with_colors_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/read_las_example.cpp", "Point_set_processing_3_2read_las_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/write_ply_points_example.cpp", "Point_set_processing_3_2write_ply_points_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/average_spacing_example.cpp", "Point_set_processing_3_2average_spacing_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/scale_estimation_example.cpp", "Point_set_processing_3_2scale_estimation_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/scale_estimation_2d_example.cpp", "Point_set_processing_3_2scale_estimation_2d_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_OpenGR.cpp", "Point_set_processing_3_2registration_with_OpenGR_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_pointmatcher.cpp", "Point_set_processing_3_2registration_with_pointmatcher_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_opengr_pointmatcher_pipeline.cpp", "Point_set_processing_3_2registration_with_opengr_pointmatcher_pipeline_8cpp-example.html", null ],
    [ "Point_set_processing_3/clustering_example.cpp", "Point_set_processing_3_2clustering_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/remove_outliers_example.cpp", "Point_set_processing_3_2remove_outliers_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/grid_simplification_example.cpp", "Point_set_processing_3_2grid_simplification_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/grid_simplify_indices.cpp", "Point_set_processing_3_2grid_simplify_indices_8cpp-example.html", null ],
    [ "Point_set_processing_3/hierarchy_simplification_example.cpp", "Point_set_processing_3_2hierarchy_simplification_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/jet_smoothing_example.cpp", "Point_set_processing_3_2jet_smoothing_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/normals_example.cpp", "Point_set_processing_3_2normals_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/orient_scanlines_example.cpp", "Point_set_processing_3_2orient_scanlines_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/wlop_simplify_and_regularize_point_set_example.cpp", "Point_set_processing_3_2wlop_simplify_and_regularize_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/bilateral_smooth_point_set_example.cpp", "Point_set_processing_3_2bilateral_smooth_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/edge_aware_upsample_point_set_example.cpp", "Point_set_processing_3_2edge_aware_upsample_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/edges_example.cpp", "Point_set_processing_3_2edges_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/structuring_example.cpp", "Point_set_processing_3_2structuring_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/callback_example.cpp", "Point_set_processing_3_2callback_example_8cpp-example.html", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Point_set_processing_3/examples.js <==
var examples =
[
    [ "Point_set_processing_3/read_write_xyz_point_set_example.cpp", "Point_set_processing_3_2read_write_xyz_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/read_ply_points_with_colors_example.cpp", "Point_set_processing_3_2read_ply_points_with_colors_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/read_las_example.cpp", "Point_set_processing_3_2read_las_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/write_ply_points_example.cpp", "Point_set_processing_3_2write_ply_points_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/average_spacing_example.cpp", "Point_set_processing_3_2average_spacing_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/scale_estimation_example.cpp", "Point_set_processing_3_2scale_estimation_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/scale_estimation_2d_example.cpp", "Point_set_processing_3_2scale_estimation_2d_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_OpenGR.cpp", "Point_set_processing_3_2registration_with_OpenGR_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_pointmatcher.cpp", "Point_set_processing_3_2registration_with_pointmatcher_8cpp-example.html", null ],
    [ "Point_set_processing_3/registration_with_opengr_pointmatcher_pipeline.cpp", "Point_set_processing_3_2registration_with_opengr_pointmatcher_pipeline_8cpp-example.html", null ],
    [ "Point_set_processing_3/clustering_example.cpp", "Point_set_processing_3_2clustering_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/remove_outliers_example.cpp", "Point_set_processing_3_2remove_outliers_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/grid_simplification_example.cpp", "Point_set_processing_3_2grid_simplification_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/grid_simplify_indices.cpp", "Point_set_processing_3_2grid_simplify_indices_8cpp-example.html", null ],
    [ "Point_set_processing_3/hierarchy_simplification_example.cpp", "Point_set_processing_3_2hierarchy_simplification_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/jet_smoothing_example.cpp", "Point_set_processing_3_2jet_smoothing_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/normals_example.cpp", "Point_set_processing_3_2normals_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/orient_scanlines_example.cpp", "Point_set_processing_3_2orient_scanlines_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/wlop_simplify_and_regularize_point_set_example.cpp", "Point_set_processing_3_2wlop_simplify_and_regularize_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/bilateral_smooth_point_set_example.cpp", "Point_set_processing_3_2bilateral_smooth_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/edge_aware_upsample_point_set_example.cpp", "Point_set_processing_3_2edge_aware_upsample_point_set_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/edges_example.cpp", "Point_set_processing_3_2edges_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/structuring_example.cpp", "Point_set_processing_3_2structuring_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/callback_example.cpp", "Point_set_processing_3_2callback_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/poisson_eliminate_example.cpp", "Point_set_processing_3_2poisson_eliminate_example_8cpp-example.html", null ],
    [ "Point_set_processing_3/poisson_eliminate_from_mesh_example.cpp", "Point_set_processing_3_2poisson_eliminate_from_mesh_example_8cpp-example.html", null ]
];
